# Changelog

## 0.2.0 (02-19-2019)
* Added create-if-not-exists for passwords [Adam Hicks]

## 0.1.2 (02-16-2019)
* Significant bug fix to allow module to use new client [Adam Hicks]

## 0.1.1 (02-15-2019)
* Significant bug fix preventing proper key filtering [Adam Hicks]

## 0.1.0 (02-14-2019)
* Implemented lookup plugin [Adam Hicks]

## 0.0.2 (02-07-2019)
* Implement SSL verification toggle [Adam Hicks]

## 0.0.1 (02-05-2019)
* Create Morpheus base module package [Adam Hicks]
